---
name: Bug report
about: Report something not working as expected.
labels: bug
---

Please check that you're running the [latest version of twitch-dl](https://github.com/ihabunek/twitch-dl/releases/latest).

**Environment**

Run `twitch-dl env` and paste the result below.

```
paste here
```

**Describe the bug**

<!-- A clear and concise description of what the bug is. -->

**To Reproduce**

<!-- Steps to reproduce the behavior, if applicable. -->
